Every story and comment from the Hacker News API, in a layout borrowed from 2001.
A comment on Python 3.11 is faster than 3.8. Parent comment
says
# opcache in 8.1 gives a nice speedup (25s to 10s)
Is the 23.7 seconds above using the 8.1 opcache?
There are no comments on this comment yet.
says
# opcache in 8.1 gives a nice speedup (25s to 10s)
Is the 23.7 seconds above using the 8.1 opcache?